@@ -19,30 +19,28 @@
 #ifndef COPY_MOVE_DIALOG_H
 #define COPY_MOVE_DIALOG_H
 
-#include <QtWidgets/qdialog.h>
-#include "ThumbsViewer.h"
+class ThumbsViewer;
+class QLabel;
+#include <QProgressDialog>
 
-class CopyMoveDialog : public QDialog {
+class CopyMoveDialog : public QProgressDialog {
 Q_OBJECT
 
-public slots:
-
-    void abort();
-
 public:
     CopyMoveDialog(QWidget *parent);
 
-    static int copyOrMoveFile(bool isCopy, QString &srcFile, QString &srcPath, QString &dstPath, QString &dstDir);
+    static int copyFile(const QString &srcPath, QString &dstPath) {
+        return copyOrMoveFile(srcPath, dstPath, true);
+    }
+    static int moveFile(const QString &srcPath, QString &dstPath) {
+        return copyOrMoveFile(srcPath, dstPath, false);
+    }
+    static int copyOrMoveFile(const QString &srcPath, QString &dstPath, bool copy);
 
-    void exec(ThumbsViewer *thumbView, QString &destDir, bool pasteInCurrDir);
-
-    int nFiles;
+    void execute(ThumbsViewer *thumbView, QString &destDir, bool pasteInCurrDir);
     int latestRow;
-
 private:
-    QLabel *opLabel;
-    QPushButton *cancelButton;
-    bool abortOp;
+    QLabel *m_label;
 };
 
-#endif // COPY_MOVE_DIALOG_H
\ No newline at end of file
+#endif // COPY_MOVE_DIALOG_H
