@@ -19,16 +19,29 @@
 #ifndef CROPRUBBERBAND_H
 #define CROPRUBBERBAND_H
 
-#include <QtWidgets>
+class QRubberBand;
+#include <QWidget>
 
 class CropRubberBand : public QWidget {
+    Q_OBJECT
 public:
-    CropRubberBand(QWidget *parent = 0);
+    CropRubberBand(QWidget *parent = nullptr);
+
+signals:
+    void cropConfirmed();
+    void selectionChanged(QRect sel);
+
+protected:
+    void showEvent(QShowEvent *event) override;
+    void keyPressEvent(QKeyEvent *event) override;
+    void mouseDoubleClickEvent(QMouseEvent *event) override;
+    void mousePressEvent(QMouseEvent *event) override;
+    void mouseMoveEvent(QMouseEvent *event) override;
+    void resizeEvent(QResizeEvent *) override;
 
 private:
     QRubberBand *rubberband;
-
-    void resizeEvent(QResizeEvent *);
+    QPoint prevPos;
 };
 
 #endif // CROPRUBBERBAND_H
