@@ -19,7 +19,15 @@
 #ifndef INFO_VIEWER_H
 #define INFO_VIEWER_H
 
-#include <QtWidgets>
+class QLabel;
+class QLineEdit;
+class QMenu;
+class QStandardItemModel;
+class QTableView;
+
+#include <QMap>
+#include <QModelIndex>
+#include <QWidget>
 
 class InfoView : public QWidget {
 Q_OBJECT
@@ -28,33 +36,35 @@ public:
     InfoView(QWidget *parent);
 
     void clear();
-
-    void addEntry(QString &key, QString &value);
-
-    void addTitleEntry(QString title);
-
-
-signals:
-
-    void updateInfo(QItemSelection dummy);
+    void hint(QString key, QString value);
+    QString html() const;
+    void read(QString imageFullPath, const QImage &histogram = QImage());
 
 public slots:
-
+    void copyEntry();
     void showInfoViewMenu(QPoint pt);
 
-    void copyEntry();
+signals:
+    void histogramClicked();
+
+protected:
+    bool eventFilter(QObject *o, QEvent *e) override;
 
 private slots:
-
     void filterItems();
 
 private:
+    void addEntry(QString key, QString value);
+    void addTitleEntry(QString title);
+
     QTableView *infoViewerTable;
     QStandardItemModel *imageInfoModel;
     QModelIndex selectedEntry;
     QMenu *infoMenu;
     QLineEdit *filterLineEdit;
-
+    QString m_currentFile;
+    QMap<QString, QString> m_hints;
+    QLabel *m_histogram;
 };
 
 #endif // INFO_VIEWER_H
