@@ -19,8 +19,8 @@
 #ifndef RENAME_DIALOG_H
 #define RENAME_DIALOG_H
 
-#include <QtWidgets/qdialog.h>
-#include <QtWidgets/qlineedit.h>
+class QLineEdit;
+#include <QDialog>
 
 class RenameDialog : public QDialog {
 Q_OBJECT
